@@ -2,11 +2,14 @@
 #'
 #' View full documentation of vis.js on network
 #' 
+#' @param viewer : Set to NULL to open in a browser
+#' 
 #' @examples
 #'
 #' # minimal example
 #' \dontrun{
 #' visDocumentation()
+#' visDocumentation(NULL)
 #' }
 #' 
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
@@ -18,8 +21,7 @@
 #'
 #' @export
 #' @importFrom  utils browseURL
-visDocumentation <- function(){
-  viewer <- getOption("viewer")
+visDocumentation <- function(viewer = getOption("viewer")){
   if (!is.null(viewer)){
     tempDir <- tempdir()
     ctrl <- file.copy(from = system.file("doc", package = "visNetwork"), 
