@@ -25,6 +25,27 @@ if (!Function.prototype.bind) {
   };
 }
 
+//--------------------------------------------
+// functions to reset edges after hard to read
+//--------------------------------------------
+
+// for edges
+function resetEdges(edges){
+  var edgesHardToRead = edges.get({
+    fields: ['id', 'color'],
+    filter: function (item) {
+      return item.color === 'rgba(200,200,200,0.5)';
+    },
+    returnType :'Array'
+  });
+            
+  // all in degree nodes get their own color and their label back
+  for (i = 0; i < edgesHardToRead.length; i++) {
+      edgesHardToRead[i].color = null;
+  }
+  edges.update(edgesHardToRead);
+}
+
 //--------------------------------------------
 // functions to reset nodes after hard to read
 //--------------------------------------------
@@ -410,20 +431,36 @@ function resetList(list_name, id, shiny_input_name) {
     Shiny.onInputChange(id + '_' + shiny_input_name, "");
   }
 }
-//unique element in array
-function uniqueArray(arr) {
-    var a = [];
-    for (var i=0, l=arr.length; i<l; i++)
-        if (a.indexOf(arr[i]) === -1 && arr[i] !== '')
-            a.push(arr[i]);
-    return a;
-}
-            
+
 //----------------------------------------------------------------
 // All available functions/methods with visNetworkProxy
 //--------------------------------------------------------------- 
 if (HTMLWidgets.shinyMode){
   
+
+  // event method
+  Shiny.addCustomMessageHandler('visShinyEvents', function(data){
+      // get container id
+      var el = document.getElementById("graph"+data.id);
+      if(el){
+        var network = el.chart;
+        
+        if(data.type === "once"){
+          for (var key in data.events) {
+            eval('network.once("' + key + '",' + data.events[key] + ')');
+          }
+        } else if(data.type === "on"){
+          for (var key in data.events) {
+            eval('network.on("' + key + '",' + data.events[key] + ')');
+          }
+        } else if(data.type === "off"){
+          for (var key in data.events) {
+            eval('network.off("' + key + '")');
+          }
+        }
+      }
+  });
+  
   // moveNode method
   Shiny.addCustomMessageHandler('visShinyMoveNode', function(data){
       // get container id
@@ -696,20 +733,18 @@ if (HTMLWidgets.shinyMode){
         if(graph){
 
           if(data.options.highlight !== undefined){
-            if(document.getElementById(el.id).highlight && !data.options.highlight){
+            if(document.getElementById(el.id).highlight && !data.options.highlight.enabled){
               // need reset nodes
               if(document.getElementById(el.id).highlightActive === true){
                 reset = true;
               }
             }
-            document.getElementById(el.id).highlight = data.options.highlight;
-            document.getElementById(el.id).degree = data.options.degree;
+            document.getElementById(el.id).highlight = data.options.highlight.enabled;
+            document.getElementById(el.id).degree = data.options.highlight.degree;
+            document.getElementById(el.id).hoverNearest = data.options.highlight.hoverNearest;
+            document.getElementById(el.id).highlightAlgorithm = data.options.highlight.algorithm;
           }
-          
-          if(data.options.hoverNearest !== undefined){
-            document.getElementById(el.id).hoverNearest = data.options.hoverNearest;
-          }
-          
+
           // init selection
           if(data.options.byselection !== undefined){
             if(data.options.byselection.selected !== undefined){
@@ -883,9 +918,18 @@ HTMLWidgets.widget({
     document.getElementById(el.id).updateNodes = false;
     document.getElementById(el.id).idselection = x.idselection.enabled;
     document.getElementById(el.id).byselection = x.byselection.enabled;
-    document.getElementById(el.id).highlight = x.highlight;
-    document.getElementById(el.id).hoverNearest = x.hoverNearest;
-    document.getElementById(el.id).degree = x.degree;
+    if(x.highlight !== undefined){
+      document.getElementById(el.id).highlight = x.highlight.enabled;
+      document.getElementById(el.id).hoverNearest = x.highlight.hoverNearest;
+      document.getElementById(el.id).degree = x.highlight.degree;
+      document.getElementById(el.id).highlightAlgorithm = x.highlight.algorithm;
+    } else {
+      document.getElementById(el.id).highlight = false;
+      document.getElementById(el.id).hoverNearest = false;
+      document.getElementById(el.id).degree = 1;
+      document.getElementById(el.id).highlightAlgorithm = "all";
+    }
+
     
     var changeInput = function(id, data) {
             Shiny.onInputChange(el.id + '_' + id, data);
@@ -911,7 +955,7 @@ HTMLWidgets.widget({
         instance.network.selectNodes([id]);
       }
       if(document.getElementById(el.id).highlight){
-        neighbourhoodHighlight(instance.network.getSelection().nodes, "click");
+        neighbourhoodHighlight(instance.network.getSelection().nodes, "click", document.getElementById(el.id).highlightAlgorithm);
       }else{
         if(init){
           selectNode = document.getElementById('nodeSelect'+el.id);
@@ -1156,13 +1200,23 @@ HTMLWidgets.widget({
       
       var mynetwork = document.getElementById('legend'+el.id);
       var lx = - mynetwork.clientWidth / 2 + 50;
-      var ly = - mynetwork.clientWidth / 2 + 50;
+      var ly = - mynetwork.clientHeight / 2 + 50;
       var step = 70;
+      var tmp_ly;
+      var tmp_lx = lx;
+      var tmp_lx2;
+      if(tmp_lx === 0){
+        tmp_lx = 1
+      }
       // want to view groups in legend
       if(x.groups && x.legend.useGroups){
         // create data
         for (var g1 = 0; g1 < x.groups.length; g1++){
-          legendnodes.add({id: null, x : lx, y : ly+g1*step, label: x.groups[g1], group: x.groups[g1], value: 1, mass:0});
+          tmp_ly =ly+g1*step;
+          if(tmp_ly === 0){
+            tmp_ly = 1
+          }
+          legendnodes.add({id: null, x : tmp_lx, y : tmp_ly, label: x.groups[g1], group: x.groups[g1], value: 1, mass:0});
         }
         // control icon size
         if(x.options.groups){
@@ -1193,8 +1247,12 @@ HTMLWidgets.widget({
         }
         // set coordinates
         for (var g = 0; g < tmpnodes.length; g++){
-          tmpnodes[g].x = lx;
-          tmpnodes[g].y = ly+(g+legendnodes.length)*step;
+          tmpnodes[g].x = tmp_lx;
+          tmp_ly = ly+(g+legendnodes.length)*step;
+          if(tmp_ly === 0){
+            tmp_ly = 1
+          }
+          tmpnodes[g].y = tmp_ly;
           if(tmpnodes[g].value === undefined && tmpnodes[g].size === undefined){
             tmpnodes[g].value = 1;
           }
@@ -1235,8 +1293,23 @@ HTMLWidgets.widget({
             legendedges[edg].width = 1;
           }
 
-          legendnodes.add({id: edg*2+1, x : lx - mynetwork.clientWidth/3, y : ly+ctrl*step, size : 0.0001, hidden : false, shape : "square", mass:0});
-          legendnodes.add({id: edg*2+2, x : lx + mynetwork.clientWidth/3, y : ly+ctrl*step, size : 0.0001, hidden : false, shape : "square", mass:0});
+          tmp_ly = ly+ctrl*step;
+          if(tmp_ly === 0){
+            tmp_ly = 1
+          }
+          
+          tmp_lx = lx - mynetwork.clientWidth/3;
+          if(tmp_lx === 0){
+            tmp_lx = 1
+          }
+          
+          tmp_lx2 = lx + mynetwork.clientWidth/3;
+          if(tmp_lx2 === 0){
+            tmp_lx2 = 1
+          }
+          
+          legendnodes.add({id: edg*2+1, x : tmp_lx, y : tmp_ly, size : 0.0001, hidden : false, shape : "square", mass:0});
+          legendnodes.add({id: edg*2+2, x : tmp_lx2, y : tmp_ly, size : 0.0001, hidden : false, shape : "square", mass:0});
           ctrl = ctrl+1;
         }
       }
@@ -1263,10 +1336,15 @@ HTMLWidgets.widget({
       
       // update coordinates if igraph
       if(x.igraphlayout !== undefined){
-        var scalex = (document.getElementById("graph"+el.id).clientWidth / 2);
+        // to improved
+        var zoomLevel = -232.622349 / (tmpnodes.length + 91.165919)  +2.516861;
+        var factor = document.getElementById("graph"+el.id).clientWidth / 1890;
+        zoomLevel = zoomLevel/factor;
+        
+        var scalex = (document.getElementById("graph"+el.id).clientWidth / 2) * zoomLevel;
         var scaley = scalex;
         if(x.igraphlayout.type !== "square"){
-          scaley = (document.getElementById("graph"+el.id).clientHeight / 2);
+          scaley = (document.getElementById("graph"+el.id).clientHeight / 2) * zoomLevel;
         }
         for (var nd in tmpnodes) {
           tmpnodes[nd].x = tmpnodes[nd].x * scalex;
@@ -1409,6 +1487,17 @@ HTMLWidgets.widget({
       }
     }
 
+    if(x.OnceEvents !== undefined){
+      for (var key in x.OnceEvents) {
+          instance.network.once(key, x.OnceEvents[key]);
+      }
+    }
+    
+    if(x.ResetEvents !== undefined){
+      for (var key in x.ResetEvents) {
+          instance.network.off(key);
+      }
+    }
     //*************************
     // Selected Highlight
     //*************************
@@ -1488,7 +1577,23 @@ HTMLWidgets.widget({
     var is_hovered = false;
     var is_clicked = false;
     
-    function neighbourhoodHighlight(params, type) {
+    //unique element in array
+    function uniqueArray(arr, exclude_cluster) {
+      var a = [];
+      for (var i=0, l=arr.length; i<l; i++){
+        if (a.indexOf(arr[i]) === -1 && arr[i] !== ''){
+          if(exclude_cluster === false){
+            a.push(arr[i]);
+          } else if(instance.network.isCluster(arr[i]) === false){
+            a.push(arr[i]);
+          }
+        }
+      }
+      return a;
+    }
+
+    function neighbourhoodHighlight(params, action_type, algorithm) {
+
       var selectNode;
       // need to update nodes before ?
       if(document.getElementById(el.id).updateNodes){
@@ -1499,7 +1604,7 @@ HTMLWidgets.widget({
       // update 
       var update = !(document.getElementById(el.id).highlightActive === false & params.length === 0) | (document.getElementById(el.id).selectActive === true & params.length === 0);
 
-      if(!(type == "hover" && is_clicked)){
+      if(!(action_type == "hover" && is_clicked)){
         if (params.length > 0) {
         
           var updateArray = [];
@@ -1530,45 +1635,181 @@ HTMLWidgets.widget({
             allNodes[nodeId].x = undefined;
             allNodes[nodeId].y = undefined;
           }
-          
-          if(degrees > 0){
-            var connectedNodes = instance.network.getConnectedNodes(selectedNode);
-          }else{
-            var connectedNodes = [selectedNode];
-          }
-          
-          var allConnectedNodes = [];
-          // get the nodes to color
-          if(degrees >= 2){
-            for (i = 2; i <= degrees; i++) {
-              var previous_connectedNodes = connectedNodes;
-              var currentlength = connectedNodes.length;
-              for (j = 0; j < currentlength; j++) {
-                connectedNodes = uniqueArray(connectedNodes.concat(instance.network.getConnectedNodes(connectedNodes[j])));
+          if(algorithm === "all"){
+            if(degrees > 0){
+              var connectedNodes = uniqueArray(instance.network.getConnectedNodes(selectedNode), true);
+            }else{
+              var connectedNodes = [selectedNode];
+            }
+            
+            var allConnectedNodes = [];
+            // get the nodes to color
+            if(degrees >= 2){
+              for (i = 2; i <= degrees; i++) {
+                var previous_connectedNodes = connectedNodes;
+                var currentlength = connectedNodes.length;
+                for (j = 0; j < currentlength; j++) {
+                  connectedNodes = uniqueArray(connectedNodes.concat(instance.network.getConnectedNodes(connectedNodes[j])), true);
+                }
+                if (connectedNodes.length === previous_connectedNodes.length) { break; }
               }
-              if (connectedNodes.length === previous_connectedNodes.length) { break; }
             }
-          }
-          // nodes to just label
-          for (j = 0; j < connectedNodes.length; j++) {
-              allConnectedNodes = allConnectedNodes.concat(instance.network.getConnectedNodes(connectedNodes[j]));
-          }
-          // all second degree nodes get a different color and their label back
-          for (i = 0; i < allConnectedNodes.length; i++) {
-            if (allNodes[allConnectedNodes[i]].hiddenLabel !== undefined) {
-              allNodes[allConnectedNodes[i]].label = allNodes[allConnectedNodes[i]].hiddenLabel;
-              allNodes[allConnectedNodes[i]].hiddenLabel = undefined;
+            // nodes to just label
+            for (j = 0; j < connectedNodes.length; j++) {
+                allConnectedNodes = allConnectedNodes.concat(instance.network.getConnectedNodes(connectedNodes[j]));
             }
+            
+            allConnectedNodes = uniqueArray(allConnectedNodes, true);
+
+            // all higher degree nodes get a different color and their label back
+            for (i = 0; i < allConnectedNodes.length; i++) {
+              if (allNodes[allConnectedNodes[i]].hiddenLabel !== undefined) {
+                allNodes[allConnectedNodes[i]].label = allNodes[allConnectedNodes[i]].hiddenLabel;
+                allNodes[allConnectedNodes[i]].hiddenLabel = undefined;
+              }
+            }
+            // all in degree nodes get their own color and their label back
+            for (i = 0; i < connectedNodes.length; i++) {
+              resetOneNode(allNodes[connectedNodes[i]], instance.network.groups, options);
+            }
+            // the main node gets its own color and its label back.
+            resetOneNode(allNodes[selectedNode], instance.network.groups, options);
+            
+          } else if(algorithm === "hierarchical"){
+            
+            // first resetEdges
+            resetEdges(edges);
+            
+            var degree_from = degrees.from;
+            var degree_to = degrees.to;
+            degrees = Math.max(degree_from, degree_to);
+            
+            var allConnectedNodes = [];
+            var currentConnectedFromNodes = [];
+            var currentConnectedToNodes = [];
+            var connectedFromNodes = [];
+            var connectedToNodes = [];
+            
+            if(degree_from > 0){
+              connectedFromNodes = edges.get({
+                fields: ['from'],
+                filter: function (item) {
+                  return item.to == selectedNode;
+                },
+                returnType :'Array'
+              });
+            }
+
+            if(degree_to > 0){
+              connectedToNodes = edges.get({
+                fields: ['to'],
+                filter: function (item) {
+                  return item.from == selectedNode;
+                },
+                returnType :'Array'
+              });
+            }
+            for (j = 0; j < connectedFromNodes.length; j++) {
+                allConnectedNodes = allConnectedNodes.concat(connectedFromNodes[j].from);
+                currentConnectedFromNodes = currentConnectedFromNodes.concat(connectedFromNodes[j].from);
+            }
+            
+            for (j = 0; j < connectedToNodes.length; j++) {
+                allConnectedNodes = allConnectedNodes.concat(connectedToNodes[j].to);
+                currentConnectedToNodes = currentConnectedToNodes.concat(connectedToNodes[j].to);
+            }
+            
+            if(degrees > 1){
+              for (i = 2; i <= degrees; i++) {
+                if(currentConnectedFromNodes.length > 0 && degrees <= degree_from){
+                  connectedFromNodes = edges.get({
+                    fields: ['from'],
+                    filter: function (item) {
+                      return indexOf.call(currentConnectedFromNodes, item.to, true) > -1;
+                    },
+                    returnType :'Array'
+                  });
+                }
+
+                if(currentConnectedToNodes.length > 0 && degrees <= degree_to){
+                  connectedToNodes = edges.get({
+                    fields: ['to'],
+                    filter: function (item) {
+                      return indexOf.call(currentConnectedToNodes, item.from, true) > -1;
+                    },
+                    returnType :'Array'
+                  });
+                }
+                
+                currentConnectedFromNodes = [];
+                currentConnectedToNodes = [];
+                
+                for (j = 0; j < connectedFromNodes.length; j++) {
+                    allConnectedNodes = allConnectedNodes.concat(connectedFromNodes[j].from);
+                    currentConnectedFromNodes = currentConnectedFromNodes.concat(connectedFromNodes[j].from);
+                }
+                
+                for (j = 0; j < connectedToNodes.length; j++) {
+                    allConnectedNodes = allConnectedNodes.concat(connectedToNodes[j].to);
+                    currentConnectedToNodes = currentConnectedToNodes.concat(connectedToNodes[j].to);
+                }
+                
+                if (currentConnectedToNodes.length === 0 &&  currentConnectedFromNodes.length === 0) { break; }
+              }
+            }
+            
+            allConnectedNodes = uniqueArray(allConnectedNodes, true).concat([selectedNode]);
+
+            var nodesWithLabel = [];
+            if(degrees > 0){
+              // nodes to just label
+              for (j = 0; j < currentConnectedToNodes.length; j++) {
+                  nodesWithLabel = nodesWithLabel.concat(instance.network.getConnectedNodes(currentConnectedToNodes[j]));
+              }
+              
+              for (j = 0; j < currentConnectedFromNodes.length; j++) {
+                  nodesWithLabel = nodesWithLabel.concat(instance.network.getConnectedNodes(currentConnectedFromNodes[j]));
+              }
+              nodesWithLabel = uniqueArray(nodesWithLabel, true);
+            } else{
+              nodesWithLabel = currentConnectedToNodes;
+              nodesWithLabel = nodesWithLabel.concat(currentConnectedFromNodes);
+              nodesWithLabel = uniqueArray(nodesWithLabel, true);
+            }
+
+            // all higher degree nodes get a different color and their label back
+            for (i = 0; i < nodesWithLabel.length; i++) {
+              if (allNodes[nodesWithLabel[i]].hiddenLabel !== undefined) {
+                allNodes[nodesWithLabel[i]].label = allNodes[nodesWithLabel[i]].hiddenLabel;
+                allNodes[nodesWithLabel[i]].hiddenLabel = undefined;
+              }
+            }
+              
+            // all in degree nodes get their own color and their label back
+            for (i = 0; i < allConnectedNodes.length; i++) {
+              resetOneNode(allNodes[allConnectedNodes[i]], instance.network.groups, options);
+            }
+            
+            // set som edges as hard to read
+            var edgesHardToRead = edges.get({
+              fields: ['id', 'color'],
+              filter: function (item) {
+                return ((indexOf.call(allConnectedNodes, item.from, true) === -1) && (indexOf.call(allConnectedNodes, item.to, true) > -1)) || ((indexOf.call(allConnectedNodes, item.from, true) > -1) && (indexOf.call(allConnectedNodes, item.to, true) === -1)) ;
+              },
+              returnType :'Array'
+            });
+            
+            // all in degree nodes get their own color and their label back
+            for (i = 0; i < edgesHardToRead.length; i++) {
+              edgesHardToRead[i].color = 'rgba(200,200,200,0.5)';
+            }
+            
+            edges.update(edgesHardToRead);
+            
           }
-          // all first degree nodes get their own color and their label back
-          for (i = 0; i < connectedNodes.length; i++) {
-            resetOneNode(allNodes[connectedNodes[i]], instance.network.groups, options);
-          }
-          // the main node gets its own color and its label back.
-          resetOneNode(allNodes[selectedNode], instance.network.groups, options);
-          
+
           if(update){
-            if(!(type == "hover")){
+            if(!(action_type == "hover")){
                is_clicked = true;
             }
             // transform the object into an array
@@ -1591,6 +1832,10 @@ HTMLWidgets.widget({
           }
           //reset nodes
           resetAllNodes(allNodes, update, nodesDataset, instance.network.groups, options)
+          if(algorithm === "hierarchical"){
+            // resetEdges
+            resetEdges(edges);
+          }
           document.getElementById(el.id).highlightActive = false;
           is_clicked = false;
         }
@@ -1639,40 +1884,46 @@ HTMLWidgets.widget({
 
     // shared click function (selectedNodes)
     document.getElementById("graph"+el.id).myclick = function(params){
-      if(document.getElementById(el.id).highlight && x.nodes){
-        neighbourhoodHighlight(params.nodes, "click");
-      }else if((document.getElementById(el.id).idselection || document.getElementById(el.id).byselection) && x.nodes){
-        onClickIDSelection(params)
-      } 
-      if(is_click_event){
-        x.events["click"](params);
+      if(instance.network.isCluster(params.nodes) === false){
+        if(document.getElementById(el.id).highlight && x.nodes){
+          neighbourhoodHighlight(params.nodes, "click", document.getElementById(el.id).highlightAlgorithm);
+        }else if((document.getElementById(el.id).idselection || document.getElementById(el.id).byselection) && x.nodes){
+          onClickIDSelection(params)
+        } 
+        if(is_click_event){
+          x.events["click"](params);
+        }
       }
     };
     
     // Set event in relation with highlightNearest      
     instance.network.on("click", function(params){
-      if(document.getElementById(el.id).highlight && x.nodes){
-        neighbourhoodHighlight(params.nodes, "click");
-      }else if((document.getElementById(el.id).idselection || document.getElementById(el.id).byselection) && x.nodes){
-        onClickIDSelection(params)
-      } 
-      if(is_click_event){
-        x.events["click"](params);
+      if(instance.network.isCluster(params.nodes) === false){
+        if(document.getElementById(el.id).highlight && x.nodes){
+          neighbourhoodHighlight(params.nodes, "click", document.getElementById(el.id).highlightAlgorithm);
+        }else if((document.getElementById(el.id).idselection || document.getElementById(el.id).byselection) && x.nodes){
+          onClickIDSelection(params)
+        } 
+        if(is_click_event){
+          x.events["click"](params);
+        }
       }
     });
     
     instance.network.on("hoverNode", function(params){
-      if(document.getElementById(el.id).hoverNearest && x.nodes){
-        neighbourhoodHighlight([params.node], "hover");
-      } 
-      if(is_hoverNode_event){
-        x.events["hoverNode"](params);
+      if(instance.network.isCluster(params.nodes) === false){
+        if(document.getElementById(el.id).hoverNearest && x.nodes){
+          neighbourhoodHighlight([params.node], "hover", document.getElementById(el.id).highlightAlgorithm);
+        } 
+        if(is_hoverNode_event){
+          x.events["hoverNode"](params);
+        }
       }
     });
 
     instance.network.on("blurNode", function(params){
       if(document.getElementById(el.id).hoverNearest && x.nodes){
-        neighbourhoodHighlight([], "hover");
+        neighbourhoodHighlight([], "hover", document.getElementById(el.id).highlightAlgorithm);
       }      
       if(is_blurNode_event){
         x.events["blurNode"](params);
@@ -1789,7 +2040,15 @@ HTMLWidgets.widget({
       instance.network.on("doubleClick", function (params) {
         if (params.nodes.length == 1) {
           if (instance.network.isCluster(params.nodes[0]) == true) {
-            instance.network.openCluster(params.nodes[0]);
+            instance.network.openCluster(params.nodes[0], {releaseFunction : function(clusterPosition, containedNodesPositions) {
+              //console.info(clusterPosition)
+              //console.info(containedNodesPositions)
+              //var newPositions = {};
+              // clusterPosition = {x:clusterX, y:clusterY};
+              // containedNodesPositions = {nodeId:{x:nodeX,y:nodeY}, nodeId2....}
+              //newPositions[nodeId] = {x:newPosX, y:newPosY};
+              return containedNodesPositions;
+            }});
             instance.network.fit()
           }
         }
@@ -1863,18 +2122,23 @@ HTMLWidgets.widget({
                   var totalMass = 0;
                   for (var i = 0; i < childNodes.length; i++) {
                       totalMass += childNodes[i].mass;
-                      if(i === 0){
-                        clusterOptions.shape =  childNodes[i].shape;
-                      }else{
-                        if(childNodes[i].shape !== clusterOptions.shape){
-                          clusterOptions.shape = 'database';
+                      if(x.clusteringColor.force === false){
+                        if(i === 0){
+                          clusterOptions.shape =  childNodes[i].shape;
+                        }else{
+                          if(childNodes[i].shape !== clusterOptions.shape){
+                            clusterOptions.shape = x.clusteringColor.shape;
+                          }
                         }
+                      } else {
+                        clusterOptions.shape = x.clusteringColor.shape;
                       }
+
                   }
                   clusterOptions.value = totalMass;
                   return clusterOptions;
               },
-              clusterNodeProperties: {id: 'cluster:' + color, borderWidth: 3, color:color, label:'Cluster on color:' + color}
+              clusterNodeProperties: {id: 'cluster:' + color, borderWidth: 3, color:color, label: x.clusteringColor.label + color}
           }
           instance.network.cluster(clusterOptionsByData);
         }
@@ -1902,22 +2166,27 @@ HTMLWidgets.widget({
                   var totalMass = 0;
                   for (var i = 0; i < childNodes.length; i++) {
                       totalMass += childNodes[i].mass;
-                      if(i === 0){
-                        clusterOptions.shape =  childNodes[i].shape;
-                        clusterOptions.color =  childNodes[i].color.background;
-                      }else{
-                        if(childNodes[i].shape !== clusterOptions.shape){
-                          clusterOptions.shape = 'database';
-                        }
-                        if(childNodes[i].color.background !== clusterOptions.color){
-                          clusterOptions.color = 'grey';
+                      if(x.clusteringGroup.force === false){
+                        if(i === 0){
+                          clusterOptions.shape =  childNodes[i].shape;
+                          clusterOptions.color =  childNodes[i].color.background;
+                        }else{
+                          if(childNodes[i].shape !== clusterOptions.shape){
+                            clusterOptions.shape = x.clusteringGroup.shape;
+                          }
+                          if(childNodes[i].color.background !== clusterOptions.color){
+                            clusterOptions.color = x.clusteringGroup.color;
+                          }
                         }
+                      } else {
+                        clusterOptions.shape = x.clusteringGroup.shape;
+                        clusterOptions.color = x.clusteringGroup.color;
                       }
                   }
                   clusterOptions.value = totalMass;
                   return clusterOptions;
               },
-              clusterNodeProperties: {id: 'cluster:' + group, borderWidth: 3, label:'Cluster on group:' + group}
+              clusterNodeProperties: {id: 'cluster:' + group, borderWidth: 3, label:x.clusteringGroup.label + group}
           }
           instance.network.cluster(clusterOptionsByData);
         }
@@ -2030,7 +2299,16 @@ HTMLWidgets.widget({
         instance.network.once("stabilized", function(){iconsRedraw();})
       }
     }
-  },
+    
+    /*console.info("clientWidth");
+    console.info(document.getElementById("graph"+el.id).clientWidth);
+
+    console.info("clientHeight");
+    console.info(document.getElementById("graph"+el.id).clientHeight);
+
+    console.info(instance.network);
+    console.info(instance.network.getScale());*/
+  }, 
   
   resize: function(el, width, height, instance) {
       if(instance.network)
