@@ -10,6 +10,9 @@ shiny::shinyUI(shiny::navbarPage(
   navbarMenu(
     title = "Use proxy",
     source("./src/ui/proxy_nodes_ui.R", local = TRUE)$value,
-    source("./src/ui/proxy_anim_ui.R", local = TRUE)$value
+    source("./src/ui/proxy_anim_ui.R", local = TRUE)$value,
+    source("./src/ui/proxy_update_ui.R", local = TRUE)$value,
+    source("./src/ui/proxy_options_ui.R", local = TRUE)$value,
+    source("./src/ui/proxy_select_ui.R", local = TRUE)$value
   )
 ))
